'use strict';

const fs = require('fs-extra');
const created = require('created');

const logger = created.logger;
const project = created.project;

const configFile = 'project.js';
const configFileContents = `
module.exports = {
    // List of plugins to load.
    plugins: [],
    // Configs for commands in pairs <command-name>: <command-config-object>.
    config: {},
};`;

const call = () => {
    const configFilePath = project.getPath(configFile);
    if (fs.existsSync(configFilePath)) {
        logger.error(`Project config already exists at "${configFilePath}"!`);
    }

    return new Promise((resolve, reject) => {
        fs.outputFile(configFilePath, configFileContents, (error) => {
            if (error) {
                reject(error);
            }
            logger.info(`Initialized new project config at "${configFilePath}".`);
            resolve();
        });
    });
};

module.exports = {
    call,
};
