/* eslint-env jest */
'use strict';

describe('Command', () => {
    beforeEach(() => {
        jest.resetModules();
        jest.resetAllMocks();
    });

    test('exports object.', () => {
        const task = require('../index');
        expect(typeof task).toBe('object');
    });

    test('exports call function.', () => {
        const task = require('../index');
        expect(typeof task.call).toBe('function');
    });

    test('throws when project.js file already exists.', () => {
        jest.mock('fs-extra', () => {
            return {
                existsSync: () => true,
            };
        });
        const call = require('../index').call;
        expect(() => call()).toThrow();
    });

    test('generates initial files for project.', () => {
        let generatedFiles = '';
        jest.mock('fs-extra', () => {
            return {
                existsSync: () => false,
                outputFile: (path, contents) => {
                    generatedFiles += `${contents}\n`;
                },
            };
        });
        const call = require('../index').call;
        call();
        expect(generatedFiles).toMatchSnapshot();
    });

    test('returns a promise when called.', () => {
        jest.mock('fs-extra', () => {
            return {
                existsSync: () => false,
                outputFile: () => null,
            };
        });
        const call = require('../index').call;
        expect(call() instanceof Promise).toBe(true);
    });

    test('resolves a promise when file is written.', () => {
        jest.mock('fs-extra', () => {
            return {
                existsSync: () => false,
                outputFile: (path, contents, callback) => {
                    callback();
                },
            };
        });
        const call = require('../index').call;
        return call().then((value) => expect(value).toBe(undefined));
    });

    test('rejects a promise when file write reported an error.', () => {
        jest.mock('fs-extra', () => {
            return {
                existsSync: () => false,
                outputFile: (path, contents, callback) => {
                    callback('Some file write error.');
                },
            };
        });
        const call = require('../index').call;
        return call().catch((value) => expect(typeof value).toBe('string'));
    });
});
